@@ -1,7 +1,7 @@
 # ./binding.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:e92452c8d3e28a9e27abfc9994d2007779e7f4c9
-# Generated 2020-06-12 15:58:24.210861 by PyXB version 1.2.6 using Python 3.8.2.final.0
+# Generated 2020-06-12 16:09:06.406243 by PyXB version 1.2.6 using Python 3.8.2.final.0
 # Namespace AbsentNamespace0
 
 from __future__ import unicode_literals
@@ -14,7 +14,7 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:ba179ce6-ac71-11ea-9f4b-80e65012546e')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:38defa6e-ac73-11ea-917a-80e65012546e')
 
 # Version of PyXB used to generate the bindings
 _PyXBVersion = '1.2.6'
